@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <fcntl.h>
 #include <netinet/in.h>
+#include <netinet/tcp.h>
 #include <errno.h>
 #include <syslog.h>
 #include <string.h>
@@ -208,6 +209,10 @@ typedef struct port_info
     unsigned char linestate_mask;
     unsigned char modemstate_mask;
     unsigned char last_modemstate;
+
+    /* Disable break-commands */
+    int disablebreak;
+
 } port_info_t;
 
 port_info_t *ports = NULL; /* Linked list of ports. */
@@ -378,6 +383,7 @@ init_port_data(port_info_t *port)
     port->dev_bytes_sent = 0;
     port->is_2217 = 0;
     port->break_set = 0;
+    port->disablebreak = 0;
 }
 
 void
@@ -913,6 +919,14 @@ setup_tcp_port(port_info_t *port)
 	syslog(LOG_ERR, "Could not fcntl the tcp port %s: %m", port->portname);
 	return -1;
     }
+    options = 1;
+    if (setsockopt(port->tcpfd, IPPROTO_TCP, TCP_NODELAY,
+		   (char *) &options, sizeof(options)) == -1) {
+	close(port->tcpfd);
+	syslog(LOG_ERR, "Could not enable TCP_NODELAY tcp port %s: %m",
+	       port->portname);
+	return -1;
+    }
 
 #ifdef HAVE_TCPD_H
     {
@@ -973,8 +987,10 @@ setup_tcp_port(port_info_t *port)
 	return -1;
     }
 
-    if (port->enabled != PORT_RAWLP &&
-              tcsetattr(port->devfd, TCSANOW, &(port->termctl)) == -1) {
+    if (port->enabled != PORT_RAWLP
+	&& !port->disablebreak
+        && tcsetattr(port->devfd, TCSANOW, &(port->termctl)) == -1)
+    {
 	close(port->tcpfd);
 	close(port->devfd);
 	syslog(LOG_ERR, "Could not set up device %s for port %s: %m",
@@ -989,15 +1005,10 @@ setup_tcp_port(port_info_t *port)
     /* Turn off BREAK. */
     if (port->enabled != PORT_RAWLP &&
               ioctl(port->devfd, TIOCCBRK) == -1) {
-	close(port->tcpfd);
-	close(port->devfd);
+	/* Probably not critical, but we should at least log something. */
 	syslog(LOG_ERR, "Could not turn off break for device %s port %s: %m",
 	       port->devname,
 	       port->portname);
-#ifdef USE_UUCP_LOCKING
-	uucp_rm_lock(port->devname);
-#endif /* USE_UUCP_LOCKING */
-	return -1;
     }
     port->is_2217 = 0;
     port->break_set = 0;
@@ -1317,7 +1328,7 @@ got_timeout(selector_t  *sel,
 	if (modemstate != port->last_modemstate) {
 	    unsigned char data[3];
 	    data[0] = TN_OPT_COM_PORT;
-	    data[1] = 7; /* Notify modemstate */
+	    data[1] = 107; /* Notify modemstate */
 	    data[2] = modemstate;
 	    port->last_modemstate = modemstate;
 	    telnet_send_option(&port->tn_data, data, 3);
@@ -1391,11 +1402,10 @@ portconfig(char *portnum,
     devinit(&(new_port->termctl));
 
     if (devconfig(devcfg, &(new_port->termctl), &new_port->allow_2217,
-		  &new_port->banner)
-	== -1)
+		  &new_port->disablebreak, &new_port->banner) == -1)
     {
-	rv = "device configuration invalid";
-	goto errout;
+	  rv = "device configuration invalid";
+	  goto errout;
     }
 
     new_port->devname = malloc(strlen(devname) + 1);
@@ -1818,7 +1828,7 @@ setportdevcfg(struct controller_info *cntlr, char *portspec, char *devcfg)
 	controller_output(cntlr, "\n\r", 2);
     } else {
 	if (devconfig(devcfg, &(port->termctl), &port->allow_2217,
-		      &port->banner) == -1)
+		      &port->disablebreak, &port->banner) == -1)
 	{
 	    char *err = "Invalid device config\n\r";
 	    controller_output(cntlr, err, strlen(err));
@@ -2060,7 +2070,7 @@ com_port_will(void *cb_data)
     
     /* send a modemstate notify */
     data[0] = TN_OPT_COM_PORT;
-    data[1] = 7; /* Notify modemstate */
+    data[1] = 107; /* Notify modemstate */
     data[2] = 0;
     if (ioctl(port->devfd, TIOCMGET, &val) != -1) {
 	if (val & TIOCM_CD)
@@ -2091,7 +2101,7 @@ com_port_handler(void *cb_data, unsigned char *option, int len)
     switch (option[1]) {
     case 0: /* SIGNATURE? */
 	outopt[0] = 44;
-	outopt[1] = 0;
+	outopt[1] = 100;
 	strcpy((char *) outopt+2, "ser2net");
 	telnet_send_option(&port->tn_data, outopt, 9);
 	break;
